TvOSNativeBindings class
FFI bindings to the native flutter_tvos C functions.
On tvOS, the native code is statically linked into the app process via CocoaPods, so we use DynamicLibrary.process() to look up symbols.
For testing, subclass this and override the getters. Use the
TvOSNativeBindings._fake named constructor to avoid FFI initialization.
Constructors
- TvOSNativeBindings()
- Creates bindings that look up native symbols in the current process.
- TvOSNativeBindings.forTesting()
- Constructor for fakes/mocks — skips FFI initialization.
Properties
- deviceModel → String
-
no setter
- displayHeight → int
-
no setter
- displayResolution → String
-
no setter
- displayWidth → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSimulator → bool
-
no setter
- isTvOS → bool
-
no setter
- machineId → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supports4K → bool
-
no setter
- supportsHDR → bool
-
no setter
- supportsMultiUser → bool
-
no setter
- systemVersion → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited